@@ -21,7 +21,7 @@
 // LAPACK++ was funded in part by the U.S. Department of Energy, the
 // National Science Foundation and the State of Tennessee.
 //
-// Modifications Copyright (C) 2000-2001 the R Development Core Team
+// Modifications Copyright (C) 2000-2002 the R Development Core Team
 
 #ifndef _LA_ROW_VECTOR_DOUBLE_H_
 #define _LA_ROW_VECTOR_DOUBLE_H_
@@ -68,14 +68,14 @@ public:
     inline LaRowVectorDouble& copy(const LaMatDouble &);
     inline LaRowVectorDouble* clone() const;
     
-    const double& operator()(int i, int j) const
+    double operator()(int i, int j) const
 	{ return operator()(0,j); }
 
     double& operator()(int i, int j)
 	{ return operator()(0,j); }
 
     inline double& operator()(int i);
-    inline const double& operator()(int i) const ;
+    inline double operator()(int i) const ;
     inline LaRowVectorDouble operator()(const LaIndex&);
 
     inline LaRowVectorDouble& operator=(const LaMatDouble &A);
@@ -108,7 +108,7 @@ inline double& LaRowVectorDouble::operator()(int i)
     return LaGenMatDouble::operator()(0,i);
 }
 
-inline const double& LaRowVectorDouble::operator()(int i) const
+inline double LaRowVectorDouble::operator()(int i) const
 { 
     return LaGenMatDouble::operator()(0,i);
 }
