@@ -21,7 +21,7 @@
 // LAPACK++ was funded in part by the U.S. Department of Energy, the
 // National Science Foundation and the State of Tennessee.
 //
-// Modifications Copyright (C) 2000-2000 the R Development Core Team
+// Modifications Copyright (C) 2000-2000, 2002 the R Development Core Team
 //
 
 #include "lafnames.h"
@@ -29,6 +29,8 @@
 #include "blas3.h"
 #include "vi.h"
 
+#include <valarray>
+
 double LaUnitUpperTriangMatDouble::outofbounds_ = 0; // initialize outofbounds.
 
 double& LaUnitUpperTriangMatDouble::operator()(int i, int j)
@@ -49,7 +51,7 @@ double& LaUnitUpperTriangMatDouble::operator()(int i, int j)
 	return data_(i,j);
 }
 
-const double& LaUnitUpperTriangMatDouble::operator()(int i, int j) const
+double LaUnitUpperTriangMatDouble::operator()(int i, int j) const
 {
 
 #ifdef UNIT_UPPER_INDEX_CHK
@@ -90,7 +92,7 @@ LaMatDouble& LaUnitUpperTriangMatDouble::operator=(double s)
     return *this;
 }
 
-ostream& LaUnitUpperTriangMatDouble::printMatrix(ostream& s) const
+std::ostream& LaUnitUpperTriangMatDouble::printMatrix(std::ostream& s) const
 {
     if (*info_) {   // print out only matrix info, not actual values
 	*info_ = 0; // reset the flag
@@ -107,7 +109,7 @@ ostream& LaUnitUpperTriangMatDouble::printMatrix(ostream& s) const
 		if (j > i)
 		    s << (*this)(i,j) << "  ";
 	    }
-	    s << endl;
+	    s << std::endl;
 	}
     }
     return s;
@@ -129,7 +131,7 @@ LaUnitUpperTriangMatDouble* LaUnitUpperTriangMatDouble::solve() const
 LaMatDouble& LaUnitUpperTriangMatDouble::solve(LaMatDouble& B) const
 {				// in-place solution
     F77_CALL(dtrsm)('L', 'U', 'N', 'U', size(0), B.size(1), 1.0,
-		    &data_(0,0), gdim(0), &B(0,0), B.gdim(0));
+                    data_.addr(), gdim(0), B.addr(), B.gdim(0));
     return B;
 }
 
@@ -143,17 +145,17 @@ double LaUnitUpperTriangMatDouble::norm(char which) const
 {
     VectorDouble work(size(0)); // only needed for Infinity norm
     return F77_CALL(dlantr)(which, 'U', 'U', size(0), size(1),
-			    &(*this)(0,0), gdim(0), &work(0));
+                            this->addr(), gdim(0), &work(0));
 }
 
 double LaUnitUpperTriangMatDouble::rcond(char which) const
 {
     double val;
-    VectorDouble work(3 * size(0));
+    std::valarray<double> work(3 * size(0));
     int info;
-    VectorInt iwork(size(0));
-    F77_CALL(dtrcon)(which, 'U', 'U', size(0), &(*this)(0,0),
-		     gdim(0), val, &work(0), &iwork(0), info);
+    std::valarray<int> iwork(size(0));
+    F77_CALL(dtrcon)(which, 'U', 'U', size(0), this->addr(),
+                     gdim(0), val, &work[0], &iwork[0], info);
     return val;
 }
 
@@ -161,8 +163,8 @@ SEXP LaUnitUpperTriangMatDouble::asSEXP() const
 {
     int m = size(0), n = size(1);
     SEXP val = PROTECT(allocMatrix(REALSXP, m, n));
-    F77_CALL(dlacpy)('U', m, n, &(*this)(0,0), gdim(0),
-		     REAL(val), m);
+    F77_CALL(dlacpy)('U', m, n, this->addr(), gdim(0),
+                     REAL(val), m);
     int ldiag = (m < n) ? m : n;
     for (int i = 0; i < ldiag; i++) // ensure the diagonal entries are 1.0
 	REAL(val)[i * (m + 1)] = 1.0;
